@@ -45,10 +45,10 @@ extern "C"
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kfilemetainfo.h>
-#include <kio/netaccess.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdefilemetainfo.h>
+#include <tdeio/netaccess.h>
 
 // libKipi includes.
 
