@@ -45,8 +45,8 @@
 
 #include <kstandarddirs.h>
 #include <kcursor.h>
-#include <kglobal.h> 
-#include <kapplication.h>
+#include <tdeglobal.h> 
+#include <tdeapplication.h>
 
 // Local includes.
 
