@@ -45,7 +45,7 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 // Local includes.
 
