@@ -51,17 +51,17 @@
 
 // KDE includes.
 
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kimageio.h>
-#include <kaboutdata.h>
-#include <kmessagebox.h>
+#include <tdeaboutdata.h>
+#include <tdemessagebox.h>
 #include <kprogress.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <khelpmenu.h>
 #include <kcalendarsystem.h>
@@ -299,9 +299,9 @@ CameraUI::CameraUI(TQWidget* /*parent*/, const TQString& cameraTitle,
                      "(YYYY-MM-DD). E.g.: <i>2006-08-24</i><p>"
                      "<b>Full Text</b>: the date format is in a user-readable string. "
                      "E.g.: <i>Thu Aug 24 2006</i><p>"
-                     "<b>Local Settings</b>: the date format depending on KDE control panel settings.<p>"));
+                     "<b>Local Settings</b>: the date format depending on TDE control panel settings.<p>"));
 
-    d->advBox->insertItem(CameraUIPriv::AUTOALBUMPAGE, albumBox, SmallIconSet("folder_new"),
+    d->advBox->insertItem(CameraUIPriv::AUTOALBUMPAGE, albumBox, SmallIconSet("folder-new"),
                           i18n("Auto-creation of Albums"));
 
     // -- On the Fly options ---------------------------------------------------
@@ -345,7 +345,7 @@ CameraUI::CameraUI(TQWidget* /*parent*/, const TQString& cameraTitle,
     TQWhatsThis::add( d->losslessFormat, i18n("<p>Select your preferred lossless image file format to "
                      "convert to.  <b>Note:</b> All metadata will be preserved during the conversion."));
 
-    d->advBox->insertItem(CameraUIPriv::ONFLYPAGE, onFlyBox, SmallIconSet("run"),
+    d->advBox->insertItem(CameraUIPriv::ONFLYPAGE, onFlyBox, SmallIconSet("system-run"),
                           i18n("On the Fly Operations (JPEG only)"));
 
     d->rightSidebar->appendTab(d->advBox, SmallIcon("configure"), i18n("Settings"));
@@ -372,8 +372,8 @@ CameraUI::CameraUI(TQWidget* /*parent*/, const TQString& cameraTitle,
     pixmapLogo->setScaledContents( false );
     pixmapLogo->setSizePolicy(TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum));
     TQToolTip::add(pixmapLogo, i18n("Visit digiKam project website"));
-    KGlobal::dirs()->addResourceType("logo-digikam", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("logo-digikam", "logo-digikam.png");
+    TDEGlobal::dirs()->addResourceType("logo-digikam", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("logo-digikam", "logo-digikam.png");
     pixmapLogo->setPixmap( TQPixmap( directory + "logo-digikam.png" ) );
     pixmapLogo->setFocusPolicy(TQ_NoFocus);
 
@@ -451,7 +451,7 @@ CameraUI::CameraUI(TQWidget* /*parent*/, const TQString& cameraTitle,
 
     TQPushButton *helpButton = actionButton( Help );
     d->helpMenu = new KHelpMenu(this, kapp->aboutData(), false);
-    d->helpMenu->menu()->insertItem(SmallIcon("camera"), i18n("Camera Information"),
+    d->helpMenu->menu()->insertItem(SmallIcon("camera-photo"), i18n("Camera Information"),
                                     this, TQT_SLOT(slotInformations()), 0, CAMERA_INFO_MENU_ID, 0);
     helpButton->setPopup( d->helpMenu->menu() );
 
@@ -591,7 +591,7 @@ CameraUI::~CameraUI()
 
 void CameraUI::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Camera Settings");
     d->advBox->setCurrentIndex(config->readNumEntry("Settings Tab", CameraUIPriv::RENAMEFILEPAGE));
     d->autoRotateCheck->setChecked(config->readBoolEntry("AutoRotate", true));
@@ -623,7 +623,7 @@ void CameraUI::saveSettings()
 {
     saveDialogSize("Camera Settings");
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("Camera Settings");
     config->writeEntry("Settings Tab", d->advBox->currentIndex());
     config->writeEntry("AutoRotate", d->autoRotateCheck->isChecked());
@@ -642,7 +642,7 @@ void CameraUI::saveSettings()
 
 void CameraUI::slotProcessURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 bool CameraUI::isBusy() const
@@ -1125,8 +1125,8 @@ void CameraUI::slotDownload(bool onlySelected, bool deleteAfter, Album *album)
                                       "to download and process selected pictures from camera.\n\n"
                                       "Estimated space require: %1\n"
                                       "Available free space: %2")
-                                      .arg(KIO::convertSizeFromKB(dSize))
-                                      .arg(KIO::convertSizeFromKB(d->freeSpaceWidget->kBAvail())));
+                                      .arg(TDEIO::convertSizeFromKB(dSize))
+                                      .arg(TDEIO::convertSizeFromKB(d->freeSpaceWidget->kBAvail())));
         return;
     }
 
