@@ -38,9 +38,9 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
 #include <klineedit.h>
 #include <knuminput.h>
@@ -219,7 +219,7 @@ RenameCustomizer::RenameCustomizer(TQWidget* parent, const TQString& cameraTitle
                     "(YYYY-MM-DD). E.g.: <i>2006-08-24T14:26:18</i></p>"
                     "<p><b>Full Text</b>: the date format is a user-readable string. "
                     "E.g.: <i>Thu Aug 24 14:26:18 2006</i></p>"
-                    "<p><b>Local Settings</b>: the date format depending on KDE control panel settings.</p>"
+                    "<p><b>Local Settings</b>: the date format depending on TDE control panel settings.</p>"
                     "<p><b>Advanced:</b> allows the user to specify a custom date format.</p>"));
     d->dateTimeButton = new TQPushButton(SmallIcon("configure"), TQString(), dateTimeWidget);
     TQSizePolicy policy = d->dateTimeButton->sizePolicy();
@@ -464,7 +464,7 @@ void RenameCustomizer::slotDateTimeButtonClicked()
 
 void RenameCustomizer::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     
     config->setGroup("Camera Settings");
     bool def         = config->readBoolEntry("Rename Use Default", true);
@@ -507,7 +507,7 @@ void RenameCustomizer::readSettings()
 
 void RenameCustomizer::saveSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     config->setGroup("Camera Settings");
     config->writeEntry("Rename Use Default", d->renameDefault->isChecked());
