@@ -36,7 +36,7 @@
 // KDE includes.
 
 #include <kdialogbase.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kservice.h>
 #include <krun.h>
 #include <ktrader.h>
@@ -45,7 +45,7 @@
 #include <kdatetbl.h>
 #include <kiconloader.h>
 #include <kprocess.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 // Local includes.
 
@@ -108,7 +108,7 @@ public:
 
     TQToolButton       *cornerButton;
 
-    KPopupFrame       *panIconPopup;
+    TDEPopupFrame       *panIconPopup;
 
     PanIconWidget     *panIconWidget;
 
@@ -126,8 +126,8 @@ LightTablePreview::LightTablePreview(TQWidget *parent)
     d = new LightTablePreviewPriv;
 
     // get preview size from screen size, but limit from VGA to WTQXGA
-    d->previewSize = TQMAX(KApplication::desktop()->height(),
-                          KApplication::desktop()->width());
+    d->previewSize = TQMAX(TDEApplication::desktop()->height(),
+                          TDEApplication::desktop()->width());
     if (d->previewSize < 640)
         d->previewSize = 640;
     if (d->previewSize > 2560)
@@ -356,18 +356,18 @@ void LightTablePreview::slotContextMenu()
     KMimeType::Ptr mimePtr = KMimeType::findByURL(url, 0, true, true);
 
     TQValueVector<KService::Ptr> serviceVector;
-    KTrader::OfferList offers = KTrader::self()->query(mimePtr->name(), "Type == 'Application'");
+    TDETrader::OfferList offers = TDETrader::self()->query(mimePtr->name(), "Type == 'Application'");
 
     TQPopupMenu openWithMenu;
 
-    KTrader::OfferList::Iterator iter;
+    TDETrader::OfferList::Iterator iter;
     KService::Ptr ptr;
     int index = 100;
 
     for( iter = offers.begin(); iter != offers.end(); ++iter )
     {
         ptr = *iter;
-        openWithMenu.insertItem( ptr->pixmap(KIcon::Small), ptr->name(), index++);
+        openWithMenu.insertItem( ptr->pixmap(TDEIcon::Small), ptr->name(), index++);
         serviceVector.push_back(ptr);
     }
 
@@ -376,7 +376,7 @@ void LightTablePreview::slotContextMenu()
     //-- Zoom actions -----------------------------------------------
 
     popmenu.insertItem(SmallIcon("viewmag"), i18n("Zoom in"), 17);
-    popmenu.insertItem(SmallIcon("viewmag-"), i18n("Zoom out"), 18);
+    popmenu.insertItem(SmallIcon("zoom-out"), i18n("Zoom out"), 18);
     popmenu.insertItem(SmallIcon("view_fit_window"), i18n("Fit to &Window"), 19);
 
     //-- Edit actions -----------------------------------------------
@@ -537,7 +537,7 @@ void LightTablePreview::slotCornerButtonPressed()
         d->panIconPopup = 0;
     }
 
-    d->panIconPopup    = new KPopupFrame(this);
+    d->panIconPopup    = new TDEPopupFrame(this);
     PanIconWidget *pan = new PanIconWidget(d->panIconPopup);
     pan->setImage(180, 120, getImage());
     d->panIconPopup->setMainWidget(pan);
